@@ -44,7 +44,10 @@ ViewerWindow::~ViewerWindow()
 
 ViewerWindow::UniquePointer ViewerWindow::makeUnique(Mode mode, QQmlEngine *engine, QWindow *parent)
 {
-    return UniquePointer(new ViewerWindow(mode, engine, parent), &SpectacleWindow::deleter);
+    return UniquePointer(new ViewerWindow(mode, engine, parent), [](ViewerWindow *window){
+        s_viewerWindowInstance = nullptr;
+        deleter(window);
+    });
 }
 
 ViewerWindow *ViewerWindow::instance()
@@ -54,12 +57,12 @@ ViewerWindow *ViewerWindow::instance()
 
 QSize ViewerWindow::imageSize() const
 {
-    return ExportManager::instance()->pixmap().size();
+    return ExportManager::instance()->image().size();
 }
 
 qreal ViewerWindow::imageDpr() const
 {
-    return ExportManager::instance()->pixmap().devicePixelRatio();
+    return ExportManager::instance()->image().devicePixelRatio();
 }
 
 void ViewerWindow::setMode(ViewerWindow::Mode mode)
