@@ -6,21 +6,37 @@
 #pragma once
 
 #include "Platform.h"
+#include "VideoPlatform.h"
 
-class PlatformNull final: public Platform
+class PlatformNull final : public Platform
 {
     Q_OBJECT
 
-    public:
-
+public:
     explicit PlatformNull(QObject *parent = nullptr);
-    virtual ~PlatformNull() = default;
+    ~PlatformNull() override = default;
 
-    QString platformName() const override final;
     GrabModes supportedGrabModes() const override final;
     ShutterModes supportedShutterModes() const override final;
 
-    public Q_SLOTS:
+public Q_SLOTS:
 
     void doGrab(Platform::ShutterMode theShutterMode, Platform::GrabMode theGrabMode, bool theIncludePointer, bool theIncludeDecorations) override final;
 };
+
+class VideoPlatformNull final : public VideoPlatform
+{
+    Q_OBJECT
+
+public:
+    explicit VideoPlatformNull(QObject *parent = nullptr);
+
+    RecordingModes supportedRecordingModes() const override;
+    void startRecording(const QString &path, RecordingMode recordingMode, const RecordingOption &option, bool includePointer) override;
+    void finishRecording() override;
+
+    QString extension() const override;
+
+private:
+    QString m_path;
+};
